@@ -1,11 +1,11 @@
 import getpass
-syleD=object
-sylek=staticmethod
-syled=False
-syleq=Exception
-syleO=None
-syleF=input
-sylen=list
+uwWDp=object
+uwWDo=staticmethod
+uwWDc=False
+uwWDg=Exception
+uwWDq=None
+uwWDB=input
+uwWDP=list
 import json
 import logging
 import sys
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import load_file,safe_requests,save_file,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(syleD):
- @sylek
+class AuthProvider(uwWDp):
+ @uwWDo
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @sylek
+ @uwWDo
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @sylek
- def get(provider,raise_error=syled):
+ @uwWDo
+ def get(provider,raise_error=uwWDc):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise syleq(msg)
-   return syleO
+    raise uwWDg(msg)
+   return uwWDq
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @sylek
+ @uwWDo
  def name():
   return "internal"
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or "{}"))
    return result["token"]
-  except syleq:
+  except uwWDg:
    pass
  def read_credentials(self,username):
   print("Please provide your login credentials below")
   if not username:
    sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=syleF()
+   username=uwWDB()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise syleq("Not implemented")
-def login(provider,username=syleO):
+  raise uwWDg("Not implemented")
+def login(provider,username=uwWDq):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=sylen(AuthProvider.providers().keys())
-  raise syleq('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=uwWDP(AuthProvider.providers().keys())
+  raise uwWDg('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise syleq("Unable to verify login credentials - please try again")
+  raise uwWDg("Unable to verify login credentials - please try again")
  configs=load_config_file()
  configs["login"]={"provider":provider,"username":username,"token":token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
