@@ -1,7 +1,7 @@
 import logging
-iMhUX=False
-iMhUo=True
-iMhUC=Exception
+BqFEC=False
+BqFEA=True
+BqFEG=Exception
 import os
 import traceback
 import localstack
@@ -82,18 +82,18 @@ def setup_ssl_cert():
    return
  download_github_artifact(SSL_CERT_URL,target_file)
 def download_github_artifact(url,target_file):
- def do_download(url,print_error=iMhUX):
+ def do_download(url,print_error=BqFEC):
   try:
    download(url,target_file)
-   return iMhUo
-  except iMhUC as e:
+   return BqFEA
+  except BqFEG as e:
    if print_error:
     LOG.info("Unable to download local test SSL certificate from %s to %s: %s %s"%(url,target_file,e,traceback.format_exc()))
  result=do_download(url)
  if not result:
   url=url.replace("https://github.com","https://cdn.jsdelivr.net/gh")
   url=url.replace("/raw/master/","@master/")
-  do_download(url,iMhUo)
+  do_download(url,BqFEA)
 def install_h2():
  target_dir=os.path.join(INFRA_DIR,"h2")
  if not os.path.exists(target_dir):
