@@ -1,15 +1,15 @@
 #!/usr/bin/env python
-NFVKT=None
-NFVKM=True
-NFVKz=Exception
-NFVKk=str
-NFVKQ=len
-NFVKU=isinstance
-NFVKX=dict
-NFVKg=hasattr
-NFVKr=int
-NFVKu=False
-NFVKh=bytes
+BrhLV=None
+BrhLg=True
+BrhLJ=Exception
+BrhLW=str
+BrhLu=len
+BrhLa=isinstance
+BrhLk=dict
+BrhLl=hasattr
+BrhLD=int
+BrhLT=False
+BrhLE=bytes
 import json
 import logging
 import os
@@ -38,32 +38,32 @@ USED_BIND_ADDRESSES=[]
 MAC_NETWORK_INTERFACE="en0"
 BUCKET_MARKER_LOCAL=(os.environ.get("BUCKET_MARKER_LOCAL")or "").strip()or "__local__"
 class FuncThread(threading.Thread):
- def __init__(self,func,params=NFVKT):
+ def __init__(self,func,params=BrhLV):
   threading.Thread.__init__(self)
-  self.daemon=NFVKM
+  self.daemon=BrhLg
   self.params=params
   self.func=func
  def run(self):
   try:
    self.func(self.params)
-  except NFVKz as e:
+  except BrhLJ as e:
    log("Error in thread function: %s %s"%(e,traceback.format_exc()))
 class ThreadedHTTPServer(ThreadingMixIn,HTTPServer):
- daemon_threads=NFVKM
+ daemon_threads=BrhLg
 class RequestHandler(BaseHTTPRequestHandler):
  def do_POST(self):
   self.read_content()
   try:
    result=self.handle_request()
    self.send_response(200)
-  except NFVKz as e:
-   error_string=NFVKk(e)
+  except BrhLJ as e:
+   error_string=BrhLW(e)
    result=json.dumps({"error":error_string})
    log("Error handling request: %s - %s"%(self.request_json,e))
    self.send_response(500)
-  self.send_header("Content-Length","%s"%NFVKQ(result)if result else 0)
+  self.send_header("Content-Length","%s"%BrhLu(result)if result else 0)
   self.end_headers()
-  if NFVKQ(result or ""):
+  if BrhLu(result or ""):
    self.wfile.write(to_bytes(result))
  def handle_request(self):
   request=self.request_json
@@ -83,17 +83,17 @@ class RequestHandler(BaseHTTPRequestHandler):
    os._exit(0)
   else:
    result={"error":'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if NFVKU(result,NFVKX)else result
+  result=json.dumps(result)if BrhLa(result,BrhLk)else result
   return result
  def read_content(self):
-  if NFVKg(self,"data_bytes"):
+  if BrhLl(self,"data_bytes"):
    return
   content_length=self.headers.get("Content-Length")
-  self.data_bytes=self.rfile.read(NFVKr(content_length))
+  self.data_bytes=self.rfile.read(BrhLD(content_length))
   self.request_json={}
   try:
    self.request_json=json.loads(self.data_bytes)
-  except NFVKz:
+  except BrhLJ:
    pass
 class RequestHandlerRoot(RequestHandler):
  def handle_request(self):
@@ -107,13 +107,13 @@ class RequestHandlerRoot(RequestHandler):
    os._exit(0)
   else:
    result={"error":'Unsupported operation "%s"'%operation}
-  result=json.dumps(result)if NFVKU(result,NFVKX)else result
+  result=json.dumps(result)if BrhLa(result,BrhLk)else result
   return result
 def s3_download(request):
  bucket=request["bucket"]
  key=request["key"]
  tmp_dir=os.environ.get("TMPDIR")or tempfile.mkdtemp()
- target_file=os.path.join(tmp_dir,request.get("file_name")or "s3file.%s"%NFVKk(uuid.uuid4()))
+ target_file=os.path.join(tmp_dir,request.get("file_name")or "s3file.%s"%BrhLW(uuid.uuid4()))
  if not os.path.exists(target_file)or request.get("overwrite"):
   if bucket==BUCKET_MARKER_LOCAL:
    shutil.copy(key,target_file)
@@ -132,14 +132,14 @@ def start_ssh_forward_proxy(options):
   sys.path.append(path)
  from tcp_proxy import server_loop
  port=options.get("port")or get_free_tcp_port()
- host=LOCAL_BIND_ADDRESS_PATTERN.replace("*",NFVKk(NFVKQ(USED_BIND_ADDRESSES)+2))
+ host=LOCAL_BIND_ADDRESS_PATTERN.replace("*",BrhLW(BrhLu(USED_BIND_ADDRESSES)+2))
  create_network_interface_alias(host)
  USED_BIND_ADDRESSES.append(host)
  log("Starting local SSH forward proxy, %s:22 -> localhost:%s"%(host,port))
  options={"bind_port":22,"bind_addr":host,"port":port}
  FuncThread(server_loop,options).start()
  return{"host":host,"forward_port":port}
-def create_network_interface_alias(address,interface=NFVKT):
+def create_network_interface_alias(address,interface=BrhLV):
  sudo_cmd="sudo"
  if is_mac_os():
   interface=interface or MAC_NETWORK_INTERFACE
@@ -156,16 +156,16 @@ def create_network_interface_alias(address,interface=NFVKT):
     assert interface not in["lo"]and not iface_addr.startswith("127.")
     run_cmd("{sudo_cmd} ifconfig {iface}:0 {addr} netmask 255.255.255.0 up".format(sudo_cmd=sudo_cmd,addr=address,iface=interface))
     return
-   except NFVKz as e:
+   except BrhLJ as e:
     log("Unable to create forward proxy on interface %s, address %s: %s"%(interface,address,e))
     pass
- raise NFVKz("Unable to create network interface")
+ raise BrhLJ("Unable to create network interface")
 def run_shell_cmd(command):
  try:
   return{"result":run_cmd(command)}
- except NFVKz as e:
-  error_string=NFVKk(e)
-  if NFVKU(e,subprocess.CalledProcessError):
+ except BrhLJ as e:
+  error_string=BrhLW(e)
+  if BrhLa(e,subprocess.CalledProcessError):
    error_string="%s: %s"%(error_string,e.output)
   return{"error":error_string}
 def get_os():
@@ -176,22 +176,22 @@ def get_os():
  return "windows"
 def run_cmd(cmd):
  log("Running command: %s"%cmd)
- return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=NFVKM))
+ return to_str(subprocess.check_output(cmd,stderr=subprocess.STDOUT,shell=BrhLg))
 def log(*args):
  print(*args)
  sys.stdout.flush()
 def is_mac_os():
  try:
-  out=to_str(subprocess.check_output("uname -a",shell=NFVKM))
+  out=to_str(subprocess.check_output("uname -a",shell=BrhLg))
   return "Darwin" in out
  except subprocess.CalledProcessError:
-  return NFVKu
+  return BrhLT
 def is_linux():
  try:
-  out=to_str(subprocess.check_output("uname -a",shell=NFVKM))
+  out=to_str(subprocess.check_output("uname -a",shell=BrhLg))
   return "Linux" in out
  except subprocess.CalledProcessError:
-  return NFVKu
+  return BrhLT
 def get_ip_address(ifname):
  import fcntl
  s=socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
@@ -203,29 +203,29 @@ def get_free_tcp_port():
  tcp.close()
  return port
 def to_bytes(obj):
- return obj.encode("utf-8")if NFVKU(obj,NFVKk)else obj
+ return obj.encode("utf-8")if BrhLa(obj,BrhLW)else obj
 def to_str(obj):
- return obj.decode("utf-8")if NFVKU(obj,NFVKh)else obj
+ return obj.decode("utf-8")if BrhLa(obj,BrhLE)else obj
 def start_server(port,handler):
  kill_server(port)
  try:
   log("Starting local daemon server on port %s"%port)
   httpd=ThreadedHTTPServer(("0.0.0.0",port),handler)
   httpd.serve_forever()
- except NFVKz:
+ except BrhLJ:
   log("Local daemon server already running, or port %s not available"%port)
   pass
 def kill_server(port):
  try:
   requests.post("http://localhost:%s"%port,data='{"op":"kill"}')
- except NFVKz:
+ except BrhLJ:
   pass
 def kill_servers():
  kill_server(DEFAULT_PORT_LOCAL_DAEMON)
  kill_server(DEFAULT_PORT_LOCAL_DAEMON_ROOT)
 def main():
  logging.basicConfig()
- daemon_type=sys.argv[1]if NFVKQ(sys.argv)>1 else "main"
+ daemon_type=sys.argv[1]if BrhLu(sys.argv)>1 else "main"
  os.environ["AWS_ACCESS_KEY_ID"]=os.environ.get("AWS_ACCESS_KEY_ID")or "test"
  os.environ["AWS_SECRET_ACCESS_KEY"]=os.environ.get("AWS_SECRET_ACCESS_KEY")or "test"
  if daemon_type=="main":
@@ -243,12 +243,12 @@ def start_in_background():
  LOG.info("Logging local daemon output to %s"%log_file)
  python_cmd=sys.executable
  cmd="%s %s"%(python_cmd,__file__)
- run(cmd,outfile=log_file,asynchronous=NFVKM)
+ run(cmd,outfile=log_file,asynchronous=BrhLg)
  LOG.info("Attempting to obtain sudo privileges for local daemon of EC2 API "+"(required to start SSH forward proxy on privileged port 22). "+"You may be asked for your sudo password.")
- run("sudo -v",stdin=NFVKM)
+ run("sudo -v",stdin=BrhLg)
  def start_root_daemon(*args):
   cmd="sudo %s %s root >> %s"%(python_cmd,__file__,log_file)
-  run(cmd,outfile=log_file,stdin=NFVKM)
+  run(cmd,outfile=log_file,stdin=BrhLg)
  FuncThread(start_root_daemon).start()
 if __name__=="__main__":
  main()
