@@ -1,18 +1,18 @@
 import json
-XpPef=None
-XpPeh=object
-XpPeH=Exception
-XpPec=set
-XpPeL=property
-XpPeN=classmethod
-XpPeq=False
-XpPed=True
-XpPel=len
-XpPeE=getattr
-XpPea=type
-XpPei=isinstance
-XpPeW=list
-XpPen=str
+hVIRc=None
+hVIRS=object
+hVIRQ=Exception
+hVIRp=set
+hVIRo=property
+hVIRq=classmethod
+hVIRM=False
+hVIRK=True
+hVIRz=len
+hVIRP=getattr
+hVIRk=type
+hVIRU=isinstance
+hVIRa=list
+hVIRt=str
 import logging
 import os
 import re
@@ -32,20 +32,20 @@ from localstack_ext.constants import API_PATH_PODS
 LOG=logging.getLogger(__name__)
 PERSISTED_FOLDERS=["api_states","dynamodb","kinesis"]
 class PodInfo:
- def __init__(self,name=XpPef,pod_size=0):
+ def __init__(self,name=hVIRc,pod_size=0):
   self.name=name
   self.pod_size=pod_size
   self.pod_size_compressed=0
   self.persisted_resource_names=[]
-class CloudPodManager(XpPeh):
+class CloudPodManager(hVIRS):
  BACKEND="_none_"
- def __init__(self,pod_name=XpPef,config=XpPef):
+ def __init__(self,pod_name=hVIRc,config=hVIRc):
   self.pod_name=pod_name
   self._pod_config=config
  def push(self)->PodInfo:
-  raise XpPeH("Not implemented")
+  raise hVIRQ("Not implemented")
  def pull(self):
-  raise XpPeH("Not implemented")
+  raise hVIRQ("Not implemented")
  def restart_container(self):
   LOG.info("Restarting LocalStack instance with updated persistence state - this may take some time ...")
   data={"action":"restart"}
@@ -59,44 +59,44 @@ class CloudPodManager(XpPeh):
    response=requests.get(url)
    content=json.loads(to_str(response.content))
    statuses=[v for k,v in content["services"].items()]
-   assert XpPec(statuses)==XpPec(["running"])
+   assert hVIRp(statuses)==hVIRp(["running"])
   retry(check_status,sleep=3,retries=10)
- @XpPeL
+ @hVIRo
  def pod_config(self):
   return self._pod_config or PodConfigManager.pod_config(self.pod_name)
- @XpPeN
- def get(cls,pod_name,pre_config=XpPef):
+ @hVIRq
+ def get(cls,pod_name,pre_config=hVIRc):
   pod_config=pre_config if pre_config else PodConfigManager.pod_config(pod_name)
   backend=pod_config.get("backend")
   for clazz in cls.__subclasses__():
    if clazz.BACKEND==backend:
     return clazz(pod_name=pod_name,config=pod_config)
-  raise XpPeH('Unable to find Cloud Pod manager implementation type "%s"'%backend)
+  raise hVIRQ('Unable to find Cloud Pod manager implementation type "%s"'%backend)
  def deploy_pod_into_instance(self,pod_path):
-  delete_pod_zip=XpPeq
+  delete_pod_zip=hVIRM
   if os.path.isdir(pod_path):
    tmpdir=new_tmp_dir()
    for folder in PERSISTED_FOLDERS:
     src_folder=os.path.join(pod_path,folder)
     tgt_folder=os.path.join(tmpdir,folder)
-    cp_r(src_folder,tgt_folder,rm_dest_on_conflict=XpPed)
+    cp_r(src_folder,tgt_folder,rm_dest_on_conflict=hVIRK)
    pod_path=create_zip_file(tmpdir)
    rm_rf(tmpdir)
-   delete_pod_zip=XpPed
+   delete_pod_zip=hVIRK
   zip_content=load_file(pod_path,mode="rb")
   url=self.get_pods_endpoint()
   result=requests.post(url,data=zip_content)
   if result.status_code>=400:
-   raise XpPeH("Unable to restore pod state via local pods management API %s (code %s): %s"%(url,result.status_code,result.content))
+   raise hVIRQ("Unable to restore pod state via local pods management API %s (code %s): %s"%(url,result.status_code,result.content))
   if delete_pod_zip:
    rm_rf(pod_path)
   else:
    return pod_path
- def get_state_zip_from_instance(self,get_content=XpPeq):
+ def get_state_zip_from_instance(self,get_content=hVIRM):
   url=f"{self.get_pods_endpoint()}/state"
   result=requests.get(url)
   if result.status_code>=400:
-   raise XpPeH("Unable to get local pod state via management API %s (code %s): %s"%(url,result.status_code,result.content))
+   raise hVIRQ("Unable to get local pod state via management API %s (code %s): %s"%(url,result.status_code,result.content))
   if get_content:
    return result.content
   zip_file=f"{new_tmp_file()}.zip"
@@ -105,7 +105,7 @@ class CloudPodManager(XpPeh):
  def get_pods_endpoint(self):
   edge_url=config.get_edge_url()
   return f"{edge_url}{API_PATH_PODS}"
- def get_pod_info(self,pod_data_dir:XpPen=XpPef):
+ def get_pod_info(self,pod_data_dir:hVIRt=hVIRc):
   result=PodInfo(self.pod_name)
   if pod_data_dir:
    result.pod_size=disk_usage(pod_data_dir)
@@ -137,14 +137,14 @@ class CloudPodManagerManaged(CloudPodManager):
  BACKEND="managed"
  def push(self)->PodInfo:
   presigned_url=self.presigned_url("push")
-  zip_data_content=self.get_state_zip_from_instance(get_content=XpPed)
-  print('Pushing state of cloud pod "%s" to backend server (%s KB)'%(self.pod_name,format_number(XpPel(zip_data_content)/1000.0)))
+  zip_data_content=self.get_state_zip_from_instance(get_content=hVIRK)
+  print('Pushing state of cloud pod "%s" to backend server (%s KB)'%(self.pod_name,format_number(hVIRz(zip_data_content)/1000.0)))
   res=safe_requests.put(presigned_url,data=zip_data_content)
   if res.status_code>=400:
-   raise XpPeH("Unable to push pod state to API (code %s): %s"%(res.status_code,res.content))
+   raise hVIRQ("Unable to push pod state to API (code %s): %s"%(res.status_code,res.content))
   print("Done.")
   result=self.get_pod_info()
-  result.pod_size_compressed=XpPel(zip_data_content)
+  result.pod_size_compressed=hVIRz(zip_data_content)
   return result
  def pull(self):
   presigned_url=self.presigned_url("pull")
@@ -160,7 +160,7 @@ class CloudPodManagerManaged(CloudPodManager):
   response=safe_requests.post("%s/cloudpods/data"%API_ENDPOINT,data,headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise XpPeH("Unable to push cloud pod to API (code %s): %s"%(response.status_code,content))
+   raise hVIRQ("Unable to push cloud pod to API (code %s): %s"%(response.status_code,content))
   content=json.loads(to_str(content))
   return content["presignedURL"]
 class CloudPodManagerGit(CloudPodManager):
@@ -171,12 +171,12 @@ class CloudPodManagerGit(CloudPodManager):
   remote_location=self.pod_config.get("url")
   try:
    porcelain.pull(repo,remote_location,refspecs=branch)
-  except XpPeH as e:
+  except hVIRQ as e:
    LOG.info("Unable to pull repo: %s"%e)
   zip_file=self.get_state_zip_from_instance()
   tmp_data_dir=new_tmp_dir()
   unzip(zip_file,tmp_data_dir)
-  is_empty_repo=b"HEAD" not in repo or repo.refs.allkeys()==XpPec([b"HEAD"])
+  is_empty_repo=b"HEAD" not in repo or repo.refs.allkeys()==hVIRp([b"HEAD"])
   if is_empty_repo:
    LOG.debug("Initializing empty repository %s"%self.clone_dir)
    init_file=os.path.join(self.clone_dir,".init")
@@ -184,7 +184,7 @@ class CloudPodManagerGit(CloudPodManager):
    porcelain.add(repo,init_file)
    porcelain.commit(repo,message="Initial commit")
   if branch not in repo:
-   porcelain.branch_create(repo,branch,force=XpPed)
+   porcelain.branch_create(repo,branch,force=hVIRK)
   self.switch_branch(branch)
   for folder in PERSISTED_FOLDERS:
    LOG.info("Copying persistence folder %s to local git repo %s"%(folder,self.clone_dir))
@@ -205,7 +205,7 @@ class CloudPodManagerGit(CloudPodManager):
   branch=self.pod_config.get("branch")
   remote_ref=b"refs/heads/%s"%to_bytes(branch)
   if remote_ref not in remote_refs:
-   raise XpPeH('Unable to find branch "%s" in remote git repo'%branch)
+   raise hVIRQ('Unable to find branch "%s" in remote git repo'%branch)
   remote_location=self.pod_config.get("url")
   self.switch_branch(branch)
   branch_ref=b"refs/heads/%s"%to_bytes(branch)
@@ -219,7 +219,7 @@ class CloudPodManagerGit(CloudPodManager):
   client,path=get_transport_and_path_from_url(self.pod_config.get("url"))
   return client,path
  def local_repo(self):
-  self.clone_dir=XpPeE(self,"clone_dir",XpPef)
+  self.clone_dir=hVIRP(self,"clone_dir",hVIRc)
   if not self.clone_dir:
    pod_dir_name=re.sub(r"(\s|/)+","",self.pod_name)
    self.clone_dir=os.path.join(config.TMP_FOLDER,"pods",pod_dir_name,"repo")
@@ -236,59 +236,59 @@ class CloudPodManagerGit(CloudPodManager):
    branch_ref=b"refs/remotes/origin/%s"%to_bytes(branch)
   repo.reset_index(repo[branch_ref].tree)
   repo.refs.set_symbolic_ref(b"HEAD",branch_ref)
-class PodConfigManagerMeta(XpPea):
+class PodConfigManagerMeta(hVIRk):
  def __getattr__(cls,attr):
   def _call(*args,**kwargs):
-   result=XpPef
+   result=hVIRc
    for manager in cls.CHAIN:
     try:
-     tmp=XpPeE(manager,attr)(*args,**kwargs)
+     tmp=hVIRP(manager,attr)(*args,**kwargs)
      if tmp:
       if not result:
        result=tmp
-      elif XpPei(tmp,XpPeW)and XpPei(result,XpPeW):
+      elif hVIRU(tmp,hVIRa)and hVIRU(result,hVIRa):
        result.extend(tmp)
-    except XpPeH:
+    except hVIRQ:
      if LOG.isEnabledFor(logging.DEBUG):
       LOG.exception("error during PodConfigManager call chain")
-   if result is not XpPef:
+   if result is not hVIRc:
     return result
-   raise XpPeH('Unable to run operation "%s" for local or remote configuration'%attr)
+   raise hVIRQ('Unable to run operation "%s" for local or remote configuration'%attr)
   return _call
-class PodConfigManager(XpPeh,metaclass=PodConfigManagerMeta):
+class PodConfigManager(hVIRS,metaclass=PodConfigManagerMeta):
  CHAIN=[]
- @XpPeN
+ @hVIRq
  def pod_config(cls,pod_name):
   pods=PodConfigManager.list_pods()
   pod_config=[pod for pod in pods if pod["pod_name"]==pod_name]
   if not pod_config:
-   raise XpPeH('Unable to find config for pod named "%s"'%pod_name)
+   raise hVIRQ('Unable to find config for pod named "%s"'%pod_name)
   return pod_config[0]
-class PodConfigManagerLocal(XpPeh):
+class PodConfigManagerLocal(hVIRS):
  CONFIG_FILE=".localstack.yml"
  def list_pods(self):
-  local_pods=self._load_config(safe=XpPed).get("pods",{})
+  local_pods=self._load_config(safe=hVIRK).get("pods",{})
   local_pods=[{"pod_name":k,"state":"Local Only",**v}for k,v in local_pods.items()]
-  existing_names=XpPec([pod["pod_name"]for pod in local_pods])
+  existing_names=hVIRp([pod["pod_name"]for pod in local_pods])
   result=[pod for pod in local_pods if pod["pod_name"]not in existing_names]
   return result
  def store_pod_metadata(self,pod_name,metadata):
   pass
- def _load_config(self,safe=XpPeq):
+ def _load_config(self,safe=hVIRM):
   try:
    return yaml.safe_load(to_str(load_file(self.CONFIG_FILE)))
-  except XpPeH:
+  except hVIRQ:
    if safe:
     return{}
-   raise XpPeH('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
-class PodConfigManagerRemote(XpPeh):
+   raise hVIRQ('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
+class PodConfigManagerRemote(hVIRS):
  def list_pods(self):
   result=[]
   auth_headers=get_auth_headers()
   response=safe_requests.get("%s/cloudpods"%API_ENDPOINT,headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise XpPeH("Unable to fetch list of pods from API (code %s): %s"%(response.status_code,content))
+   raise hVIRQ("Unable to fetch list of pods from API (code %s): %s"%(response.status_code,content))
   remote_pods=json.loads(to_str(content)).get("cloudpods",[])
   remote_pods=[{"state":"Shared",**pod}for pod in remote_pods]
   result.extend(remote_pods)
@@ -299,12 +299,12 @@ class PodConfigManagerRemote(XpPeh):
   response=safe_requests.post("%s/cloudpods"%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise XpPeH("Unable to store pod metadata in API (code %s): %s"%(response.status_code,content))
+   raise hVIRQ("Unable to store pod metadata in API (code %s): %s"%(response.status_code,content))
   return json.loads(to_str(content))
 PodConfigManager.CHAIN.append(PodConfigManagerLocal())
 PodConfigManager.CHAIN.append(PodConfigManagerRemote())
 def push_state(pod_name,args,**kwargs):
- pre_config=kwargs.get("pre_config",XpPef)
+ pre_config=kwargs.get("pre_config",hVIRc)
  backend=CloudPodManager.get(pod_name=pod_name,pre_config=pre_config)
  pod_config=clone(backend.pod_config)
  pod_info=backend.push()
@@ -312,15 +312,15 @@ def push_state(pod_name,args,**kwargs):
  pod_config["available_resources"]=pod_info.persisted_resource_names
  return pod_config
 def pull_state(pod_name,args,**kwargs):
- pre_config=kwargs.get("pre_config",XpPef)
+ pre_config=kwargs.get("pre_config",hVIRc)
  if not pod_name:
-  raise XpPeH("Need to specify a pod name")
+  raise hVIRQ("Need to specify a pod name")
  backend=CloudPodManager.get(pod_name=pod_name,pre_config=pre_config)
  backend.pull()
  print("Done.")
 def list_pods(args):
  return PodConfigManager.list_pods()
-def get_data_dir_from_container()->XpPen:
+def get_data_dir_from_container()->hVIRt:
  try:
   details=DOCKER_CLIENT.inspect_container(config.MAIN_CONTAINER_NAME)
   mounts=details.get("Mounts")
@@ -330,12 +330,12 @@ def get_data_dir_from_container()->XpPen:
    data_dir_host=[m for m in mounts if m["Destination"]==data_dir_env][0]["Source"]
    data_dir_host=re.sub(r"^(/host_mnt)?",r"",data_dir_host)
    data_dir_env=data_dir_host
-  except XpPeH:
+  except hVIRQ:
    LOG.debug(f"No docker volume for data dir '{data_dir_env}' detected")
   return data_dir_env
- except XpPeH:
+ except hVIRQ:
   LOG.warning('''Unable to determine DATA_DIR from LocalStack Docker container - please make sure $MAIN_CONTAINER_NAME is configured properly''')
-def get_persisted_resource_names(data_dir)->List[XpPen]:
+def get_persisted_resource_names(data_dir)->List[hVIRt]:
  names=[]
  with os.scandir(data_dir)as entries:
   for entry in entries:
@@ -343,7 +343,7 @@ def get_persisted_resource_names(data_dir)->List[XpPen]:
     names.append(entry.name)
  with os.scandir(os.path.join(data_dir,"api_states"))as entries:
   for entry in entries:
-   if entry.is_dir()and XpPel(os.listdir(entry.path))>0:
+   if entry.is_dir()and hVIRz(os.listdir(entry.path))>0:
     names.append(entry.name)
  LOG.debug(f"Detected state files for the following APIs: {names}")
  return names
