@@ -1,5 +1,5 @@
 import base64
-MQnOg=None
+nogAE=None
 import hmac
 import smtplib
 from base64 import b64encode
@@ -24,7 +24,7 @@ class SMTP(smtplib.SMTP):
    raise SMTPException("SMTP AUTH extension not supported by server.")
   authlist=self.esmtp_features["auth"].split()
   preferred_auths=[AUTH_CRAM_MD5,AUTH_PLAIN,AUTH_LOGIN]
-  authmethod=MQnOg
+  authmethod=nogAE
   for method in preferred_auths:
    if method in authlist:
     authmethod=method
@@ -48,7 +48,7 @@ class SMTP(smtplib.SMTP):
    tmp=self.check_codes(encoded_username,encoded_password)
    code=tmp[0]
    resp=tmp[1]
-  elif authmethod is MQnOg:
+  elif authmethod is nogAE:
    raise SMTPException("No suitable authentication method found.")
   if code not in(235,503):
    raise SMTPAuthenticationError(code,resp)
