@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-SAyJv=dict
-SAyJh=super
-SAyJH=hasattr
-SAyJK=Exception
-SAyJn=object
-SAyJY=dir
-SAyJc=None
-SAyJb=False
-SAyJL=True
-SAyJd=len
-SAyJM=set
+LNmfO=dict
+LNmfA=super
+LNmfb=hasattr
+LNmfz=Exception
+LNmfY=object
+LNmfG=dir
+LNmfT=None
+LNmfX=False
+LNmfS=True
+LNmfh=len
+LNmfB=set
 import errno
 import socket
 from select import select
 from socket import(AF_INET,AF_INET6,IPPROTO_IPV6,IPPROTO_TCP,IPV6_V6ONLY,SO_REUSEADDR,SOCK_STREAM,SOL_SOCKET,TCP_NODELAY)
-class AttrDict(SAyJv):
+class AttrDict(LNmfO):
  def __init__(self,*args,**kwargs):
-  SAyJh(AttrDict,self).__init__(*args,**kwargs)
+  LNmfA(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and SAyJH(socket,"IPV6_V6ONLY"):
+ if six and LNmfb(socket,"IPV6_V6ONLY"):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except SAyJK:
+ except LNmfz:
   pass
-class Server(SAyJn):
+class Server(LNmfY):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(SAyJn):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(SAyJn):
- def __init__(self,opt,sock,addr,SAyJY):
+class Half(LNmfY):
+ def __init__(self,opt,sock,addr,LNmfG):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.SAyJY=SAyJY
-  self.name="peer" if self.SAyJY else "client"
+  self.LNmfG=LNmfG
+  self.name="peer" if self.LNmfG else "client"
   self.queue=[]
-  self.dest=SAyJc
-  self.err=SAyJc
-  self.ready=SAyJb
+  self.dest=LNmfT
+  self.err=LNmfT
+  self.ready=LNmfX
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +72,7 @@ class Half(SAyJn):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=SAyJL
+   self.ready=LNmfS
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +81,9 @@ class Half(SAyJn):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except SAyJK as e:
+  except LNmfz as e:
    return self.error("send error",e)
-  if n!=SAyJd(self.queue[0]):
+  if n!=LNmfh(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +92,17 @@ class Half(SAyJn):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=SAyJb
+    self.ready=LNmfX
     return
    return self.error("recv socket error",e)
-  except SAyJK as e:
+  except LNmfz as e:
    return self.error("recv error",e)
-  if SAyJd(buf)==0:
+  if LNmfh(buf)==0:
    return self.error("eof",0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(SAyJn):
+class Proxy(LNmfY):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,"i")
@@ -110,7 +110,7 @@ class Proxy(SAyJn):
   self.peer=Half(opt,peer,addr,"o")
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=SAyJc
+  self.err=LNmfT
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,7 +125,7 @@ class Proxy(SAyJn):
   return self.err
 def server_loop(opt):
  qs=[]
- opt["ip6"]=opt.get("ip6",SAyJb)
+ opt["ip6"]=opt.get("ip6",LNmfX)
  opt["bind_addr"]=opt.get("bind_addr","0.0.0.0")
  opt["addr"]=opt.get("addr","127.0.0.1")
  opt["bind_port"]=opt.get("bind_port",0)
@@ -137,15 +137,15 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=SAyJM(r).union(rr)
+  r=LNmfB(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={"ip6":SAyJb,"bind_port":2223,"addr":"192.168.43.191","port":22}
- opt={"ip6":SAyJb,"bind_port":48429,"addr":"128.0.100.3","port":22}
- opt={"ip6":SAyJb,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
- opt={"ip6":SAyJb,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
+ opt={"ip6":LNmfX,"bind_port":2223,"addr":"192.168.43.191","port":22}
+ opt={"ip6":LNmfX,"bind_port":48429,"addr":"128.0.100.3","port":22}
+ opt={"ip6":LNmfX,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
+ opt={"ip6":LNmfX,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
  server_loop(opt)
 if __name__=="__main__":
  main()
