@@ -1,13 +1,13 @@
 import os
-QrOBo=True
-QrOBS=False
-QrOBv=None
-QrOBn=Exception
-QrOBP=open
-QrOBf=str
-QrOBW=dict
-QrOBX=list
-QrOBx=isinstance
+pEnmS=True
+pEnmi=False
+pEnmg=None
+pEnmG=Exception
+pEnmX=open
+pEnme=str
+pEnmR=dict
+pEnmU=list
+pEnmO=isinstance
 import sys
 from typing import Any,Callable,Dict,List
 import click
@@ -16,8 +16,8 @@ class ProCliPlugin(LocalstackCliPlugin):
  name="pro"
  def is_active(self):
   e=os.getenv("LOCALSTACK_API_KEY")
-  return QrOBo if e else QrOBS
- def attach(self,cli:LocalstackCli)->QrOBv:
+  return pEnmS if e else pEnmi
+ def attach(self,cli:LocalstackCli)->pEnmg:
   group:click.Group=cli.group
   group.add_command(cmd_login)
   group.add_command(cmd_logout)
@@ -34,7 +34,7 @@ def cmd_login(username,provider):
  try:
   auth.login(provider,username)
   console.print("successfully logged in")
- except QrOBn as e:
+ except pEnmG as e:
   console.print("authentication error: %s"%e)
 @click.command(name="logout",help="Log out and delete any session tokens")
 def cmd_logout():
@@ -42,7 +42,7 @@ def cmd_logout():
  try:
   auth.logout()
   console.print("successfully logged out")
- except QrOBn as e:
+ except pEnmG as e:
   console.print("logout error: %s"%e)
 @daemons.command(name="start",help="Start local daemon processes")
 def cmd_daemons_start():
@@ -61,7 +61,7 @@ def cmd_daemons_log():
  if not os.path.isfile(file_path):
   console.print("no log found")
  else:
-  with QrOBP(file_path,"r")as fd:
+  with pEnmX(file_path,"r")as fd:
    for line in fd:
     sys.stdout.write(line)
     sys.stdout.flush()
@@ -79,11 +79,11 @@ def cmd_pod_list():
  from localstack.utils.common import format_bytes
  from localstack_ext.bootstrap import pods_client
  try:
-  result=pods_client.list_pods(QrOBv)
+  result=pods_client.list_pods(pEnmg)
   status.stop()
   columns={"pod_name":"Name","backend":"Backend","url":"URL","size":"Size","state":"State"}
   print_table(columns,result,formatters={"size":format_bytes})
- except QrOBn as e:
+ except pEnmG as e:
   status.stop()
   if config.DEBUG:
    console.print_exception()
@@ -95,31 +95,31 @@ def cmd_pod_create():
  console.print(msg)
 @pod.command(name="push",help="Push the state of the LocalStack instance to a cloud pod")
 @click.argument("name")
-def cmd_pod_push(name:QrOBf):
+def cmd_pod_push(name:pEnme):
  from localstack_ext.bootstrap import pods_client
- pods_client.push_state(name,QrOBv)
+ pods_client.push_state(name,pEnmg)
 @pod.command(name="pull",help="Pull the state of a cloud pod into the running LocalStack instance")
 @click.argument("name")
-def cmd_pod_pull(name:QrOBf):
+def cmd_pod_pull(name:pEnme):
  from localstack_ext.bootstrap import pods_client
- pods_client.pull_state(name,QrOBv)
-def print_table(columns:Dict[QrOBf,QrOBf],rows:List[Dict[QrOBf,Any]],formatters:Dict[QrOBf,Callable[[Any],QrOBf]]=QrOBv):
+ pods_client.pull_state(name,pEnmg)
+def print_table(columns:Dict[pEnme,pEnme],rows:List[Dict[pEnme,Any]],formatters:Dict[pEnme,Callable[[Any],pEnme]]=pEnmg):
  from rich.table import Table
- if formatters is QrOBv:
-  formatters=QrOBW()
+ if formatters is pEnmg:
+  formatters=pEnmR()
  t=Table()
  for k,name in columns.items():
   t.add_column(name)
  for row in rows:
-  cells=QrOBX()
+  cells=pEnmU()
   for c in columns.keys():
    cell=row.get(c)
    if c in formatters:
     cell=formatters[c](cell)
-   if cell is QrOBv:
+   if cell is pEnmg:
     cell=""
-   if not QrOBx(cell,QrOBf):
-    cell=QrOBf(cell)
+   if not pEnmO(cell,pEnme):
+    cell=pEnme(cell)
    cells.append(cell)
   t.add_row(*cells)
  console.print(t)
