@@ -1,10 +1,9 @@
 import os
 import re
-import subprocess
 
-import six
 from localstack import config as localstack_config
 from localstack import constants as localstack_constants
+from localstack.utils.docker import DOCKER_CLIENT
 
 FALSE_STRINGS = localstack_constants.FALSE_STRINGS
 
@@ -102,17 +101,22 @@ PORT_HIVE_SERVER = 10000
 PORT_SPARK_MASTER = 7077
 PORT_SPARK_UI = 4040
 
+# Additional flags provided to the batch container
+# only flags for volumes, ports, environment variables and add-hosts are allowed
+BATCH_DOCKER_FLAGS = os.environ.get("BATCH_DOCKER_FLAGS", "")
+
 if localstack_config.DOCKER_HOST_FROM_CONTAINER == DOCKER_HOST_NAME:
     # special case when we're running tests outside of Docker
     if not localstack_config.in_docker():
         image_name = localstack_constants.DOCKER_IMAGE_NAME
-        cmd = "docker run --rm --entrypoint= -it %s bash -c 'ping -c 1 %s'" % (
-            image_name,
-            DOCKER_HOST_NAME,
-        )
         try:
-            out = subprocess.check_output(cmd, shell=True)
-            out = out.decode("utf-8") if isinstance(out, six.binary_type) else out
+            out, _ = DOCKER_CLIENT.run_container(
+                image_name,
+                remove=True,
+                entrypoint="",
+                command=["bash", "-c", "ping -c 1 %s" % DOCKER_HOST_NAME],
+            )
+            out = out.decode(localstack_config.DEFAULT_ENCODING) if isinstance(out, bytes) else out
             ip = re.match(r"PING[^\(]+\(([^\)]+)\).*", out, re.MULTILINE | re.DOTALL)
             ip = ip and ip.group(1)
             if ip:
