@@ -1,16 +1,16 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-DRzsr=staticmethod
-DRzsG=classmethod
+gzqWu=staticmethod
+gzqWo=classmethod
 from localstack.utils.aws import aws_stack
 class IoTCertificate(GenericBaseModel):
- @DRzsr
+ @gzqWu
  def cloudformation_type():
   return "AWS::IoT::Certificate"
  def fetch_state(self,stack_name,resources):
   return self.state.get("certificateId")
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("certificateId")
- @DRzsG
+ @gzqWo
  def get_deploy_templates(cls):
   def create_certificate_from_csr(resource_id,resources,*args,**kwargs):
    client=aws_stack.connect_to_service("iot")
